--[[
	
	This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike License. 
	To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/2.5/ or send 
	a letter to Creative Commons, 543 Howard Street, 5th Floor, San Francisco, California, 94105, USA.
	
]]

local tcPlayerFrameConfig_PopupOnLoad = false;

function tcPlayerFrameConfig_Command(cmd)
	tcPlayerFrameConfig:Show();
end

function tcPlayerFrameConfig_OnLoad()	
	SLASH_TCPF1 = "/tcplayerframe";
	SLASH_TCPF2 = "/tcpf";
	SlashCmdList["TCPF"] = tcPlayerFrameConfig_Command;
	tinsert(UISpecialFrames, "tcPlayerFrameConfig");
	if ( tcPlayerFrameConfig_PopupOnLoad ) then
		tcPlayerFrameConfig:Show();
	end
end

function tcPlayerFrameConfig_DecorationDropDown_OnLoad()
	UIDropDownMenu_Initialize(this, tcPlayerFrameConfig_DecorationDropDown_Initialize);
	UIDropDownMenu_SetSelectedValue(tcPlayerFrameConfig_DecorationDropDown, tcPlayerFrame_Variables["decoration"]);
end

function tcPlayerFrameConfig_DecorationDropDown_Initialize()	
	for key in tcPlayerFrame_Decorations do
		info = {};
		info.text = getglobal("TCPF_"..strupper(key));
		info.value = key;
		info.func = tcPlayerFrameConfig_DecorationDropDown_OnClick;
		UIDropDownMenu_AddButton(info);
	end
end

function tcPlayerFrameConfig_DecorationDropDown_OnClick()
	UIDropDownMenu_SetSelectedValue(tcPlayerFrameConfig_DecorationDropDown, this.value);
	tcPlayerFrame_Variables["decoration"] = this.value;
	tcPlayerFrame_UpdateDecoration();
end



function tcPlayerFrameConfig_CaptionDropDown_OnLoad()
	UIDropDownMenu_Initialize(this, tcPlayerFrameConfig_CaptionDropDown_Initialize);
end

function tcPlayerFrameConfig_CaptionDropDown_Initialize()	
	for key in tcPlayerFrame_Captions do
		info = {};
		info.text = getglobal("TCPF_"..strupper(key));
		info.value = key;
		info.func = tcPlayerFrameConfig_CaptionDropDown_OnClick;
		UIDropDownMenu_AddButton(info);
	end
end

function tcPlayerFrameConfig_CaptionDropDown_OnClick()
	UIDropDownMenu_SetSelectedValue(tcPlayerFrameConfig_CaptionDropDown, this.value);
	tcPlayerFrameConfig_UpdateItems(1);
end

function tcPlayerFrameConfig_UpdateItems(init)
	tcPlayerFrameConfig_VisibleCheckButton:Show();
	tcPlayerFrameConfig_FontSizeSlider:Show();
	tcPlayerFrameConfig_ColorSwatch:Show();
	tcPlayerFrameConfig_TextTemplateDropDown:Show();
	
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;

	tcPlayerFrameConfig_VisibleCheckButton:SetChecked(tcPlayerFrame_Captions[selectedValue]["visible"]);	
	tcPlayerFrameConfig_FontSizeSliderText:SetText(tcPlayerFrame_Captions[selectedValue]["fontsize"]);
	tcPlayerFrameConfig_ColorSwatch_NormalTexture:SetVertexColor(
		tcPlayerFrame_Captions[selectedValue]["color"]["r"],
		tcPlayerFrame_Captions[selectedValue]["color"]["g"],
		tcPlayerFrame_Captions[selectedValue]["color"]["b"]
	);
	
	if tcPlayerFrame_Captions[selectedValue]["template"] and tcPlayerFrame_TextTemplates[tcPlayerFrame_Captions[selectedValue]["template"]] then
		UIDropDownMenu_SetSelectedValue(tcPlayerFrameConfig_TextTemplateDropDown, tcPlayerFrame_Captions[selectedValue]["template"]);
		UIDropDownMenu_SetText(getglobal("TCPF_"..strupper(tcPlayerFrame_Captions[selectedValue]["template"])), tcPlayerFrameConfig_TextTemplateDropDown);
	end
	
	if init == 1 then
		tcPlayerFrameConfig_FontSizeSlider:SetValue(tcPlayerFrame_Captions[selectedValue]["fontsize"]);
	end
	
	tcPlayerFrame_UpdateCaptions();
end


function tcPlayerFrameConfig_VisibleCheckButton_OnClick()
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;
	
	if selectedValue ~= nil then
		tcPlayerFrame_Captions[selectedValue]["visible"] = tcPlayerFrameConfig_VisibleCheckButton:GetChecked();
	
		tcPlayerFrameConfig_UpdateItems(0);
	end
end


function tcPlayerFrameConfig_FontSizeSlider_OnValueChanged()
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;
	
	if selectedValue ~= nil then
		tcPlayerFrame_Captions[selectedValue]["fontsize"] = tcPlayerFrameConfig_FontSizeSlider:GetValue();
	
		tcPlayerFrameConfig_UpdateItems(0);
	end
end



function tcPlayerFrameConfig_ColorSwatch_OnClick()
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;
	
	if selectedValue ~= nil then
		ColorPickerFrame.func = tcPlayerFrameConfig_ColorSwatch_UpdateValue;
		ColorPickerFrame:SetColorRGB(
			tcPlayerFrame_Captions[selectedValue]["color"]["r"], 
			tcPlayerFrame_Captions[selectedValue]["color"]["g"], 
			tcPlayerFrame_Captions[selectedValue]["color"]["b"]
		);
		
		ShowUIPanel(ColorPickerFrame);
		ColorPickerFrame:SetFrameStrata("DIALOG");
		ColorPickerFrame:Raise();
	end
end


function tcPlayerFrameConfig_ColorSwatch_UpdateValue()
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;
	
	if selectedValue ~= nil then
		local R, G, B = ColorPickerFrame:GetColorRGB();
		
		tcPlayerFrame_Captions[selectedValue]["color"]["r"] = R;
		tcPlayerFrame_Captions[selectedValue]["color"]["g"] = G;
		tcPlayerFrame_Captions[selectedValue]["color"]["b"] = B;	
		
		tcPlayerFrameConfig_UpdateItems(0);
	end
end



function tcPlayerFrameConfig_TextTemplateDropDown_OnLoad()
	UIDropDownMenu_Initialize(this, tcPlayerFrameConfig_TextTemplateDropDown_Initialize);
end

function tcPlayerFrameConfig_TextTemplateDropDown_Initialize()	
	for key in tcPlayerFrame_TextTemplates do
		info = {};
		info.text = getglobal("TCPF_"..strupper(key));
		info.value = key;
		info.func = tcPlayerFrameConfig_TextTemplateDropDown_OnClick;
		UIDropDownMenu_AddButton(info);
	end
end

function tcPlayerFrameConfig_TextTemplateDropDown_OnClick()	
	local selectedValue = tcPlayerFrameConfig_CaptionDropDown.selectedValue;
	
	if selectedValue ~= nil then
		tcPlayerFrame_Captions[selectedValue]["template"] = this.value;
	
		tcPlayerFrameConfig_UpdateItems(0);
	end
end



